# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/api_user/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/api_user/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.api_user.v1 import api_user_pb2 as meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'meshtrade/iam/api_user/v1/service.proto\x12\x19meshtrade.iam.api_user.v1\x1a\x1b\x62uf/validate/validate.proto\x1a(meshtrade/iam/api_user/v1/api_user.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"\'\n\x11GetApiUserRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"7\n\x1aGetApiUserByKeyHashRequest\x12\x19\n\x08key_hash\x18\x01 \x01(\tR\x07keyHash\"U\n\x14\x43reateApiUserRequest\x12=\n\x08\x61pi_user\x18\x01 \x01(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x07\x61piUser\"\x15\n\x13ListApiUsersRequest\"W\n\x14ListApiUsersResponse\x12?\n\tapi_users\x18\x01 \x03(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x08\x61piUsers\":\n\x15SearchApiUsersRequest\x12!\n\x0c\x64isplay_name\x18\x01 \x01(\tR\x0b\x64isplayName\"Y\n\x16SearchApiUsersResponse\x12?\n\tapi_users\x18\x01 \x03(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x08\x61piUsers\"\xd9\x01\n\x16\x41\x63tivateApiUserRequest\x12\xbe\x01\n\x04name\x18\x01 \x01(\tB\xa9\x01\xbaH\xa5\x01r&\x10\x01\x32\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\xba\x01z\n\rname.required\x12\x35name is required and must be in format api_users/{id}\x1a\x32this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')R\x04name\"\xdb\x01\n\x18\x44\x65\x61\x63tivateApiUserRequest\x12\xbe\x01\n\x04name\x18\x01 \x01(\tB\xa9\x01\xbaH\xa5\x01r&\x10\x01\x32\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\xba\x01z\n\rname.required\x12\x35name is required and must be in format api_users/{id}\x1a\x32this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')R\x04name2\xe8\x06\n\x0e\x41piUserService\x12l\n\nGetApiUser\x12,.meshtrade.iam.api_user.v1.GetApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12q\n\rCreateApiUser\x12/.meshtrade.iam.api_user.v1.CreateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x12}\n\x0cListApiUsers\x12..meshtrade.iam.api_user.v1.ListApiUsersRequest\x1a/.meshtrade.iam.api_user.v1.ListApiUsersResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12\x83\x01\n\x0eSearchApiUsers\x12\x30.meshtrade.iam.api_user.v1.SearchApiUsersRequest\x1a\x31.meshtrade.iam.api_user.v1.SearchApiUsersResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12u\n\x0f\x41\x63tivateApiUser\x12\x31.meshtrade.iam.api_user.v1.ActivateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x12y\n\x11\x44\x65\x61\x63tivateApiUser\x12\x33.meshtrade.iam.api_user.v1.DeactivateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x12~\n\x13GetApiUserByKeyHash\x12\x35.meshtrade.iam.api_user.v1.GetApiUserByKeyHashRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x42Z\n co.meshtrade.api.iam.api_user.v1Z6github.com/meshtrade/api/go/iam/api_user/v1;api_userv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.api_user.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n co.meshtrade.api.iam.api_user.v1Z6github.com/meshtrade/api/go/iam/api_user/v1;api_userv1'
  _globals['_ACTIVATEAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ACTIVATEAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H\245\001r&\020\0012\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\272\001z\n\rname.required\0225name is required and must be in format api_users/{id}\0322this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')'
  _globals['_DEACTIVATEAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DEACTIVATEAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H\245\001r&\020\0012\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\272\001z\n\rname.required\0225name is required and must be in format api_users/{id}\0322this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')'
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUser']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_APIUSERSERVICE'].methods_by_name['CreateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['CreateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_APIUSERSERVICE'].methods_by_name['ListApiUsers']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['ListApiUsers']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_APIUSERSERVICE'].methods_by_name['SearchApiUsers']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['SearchApiUsers']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_APIUSERSERVICE'].methods_by_name['ActivateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['ActivateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_APIUSERSERVICE'].methods_by_name['DeactivateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['DeactivateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUserByKeyHash']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUserByKeyHash']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_GETAPIUSERREQUEST']._serialized_start=214
  _globals['_GETAPIUSERREQUEST']._serialized_end=253
  _globals['_GETAPIUSERBYKEYHASHREQUEST']._serialized_start=255
  _globals['_GETAPIUSERBYKEYHASHREQUEST']._serialized_end=310
  _globals['_CREATEAPIUSERREQUEST']._serialized_start=312
  _globals['_CREATEAPIUSERREQUEST']._serialized_end=397
  _globals['_LISTAPIUSERSREQUEST']._serialized_start=399
  _globals['_LISTAPIUSERSREQUEST']._serialized_end=420
  _globals['_LISTAPIUSERSRESPONSE']._serialized_start=422
  _globals['_LISTAPIUSERSRESPONSE']._serialized_end=509
  _globals['_SEARCHAPIUSERSREQUEST']._serialized_start=511
  _globals['_SEARCHAPIUSERSREQUEST']._serialized_end=569
  _globals['_SEARCHAPIUSERSRESPONSE']._serialized_start=571
  _globals['_SEARCHAPIUSERSRESPONSE']._serialized_end=660
  _globals['_ACTIVATEAPIUSERREQUEST']._serialized_start=663
  _globals['_ACTIVATEAPIUSERREQUEST']._serialized_end=880
  _globals['_DEACTIVATEAPIUSERREQUEST']._serialized_start=883
  _globals['_DEACTIVATEAPIUSERREQUEST']._serialized_end=1102
  _globals['_APIUSERSERVICE']._serialized_start=1105
  _globals['_APIUSERSERVICE']._serialized_end=1977
# @@protoc_insertion_point(module_scope)
