# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.iam.user.v1 import user_pb2 as meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#meshtrade/iam/user/v1/service.proto\x12\x15meshtrade.iam.user.v1\x1a\x1b\x62uf/validate/validate.proto\x1a meshtrade/iam/role/v1/role.proto\x1a meshtrade/iam/user/v1/user.proto\x1a%meshtrade/option/v1/method_type.proto\"\x88\x04\n\x17\x41ssignRoleToUserRequest\x12\xac\x01\n\x05\x65mail\x18\x01 \x01(\tB\x95\x01\xbaH\x91\x01r7\x10\x01\x18\xfe\x01\x32\x30^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\\.[a-zA-Z]{2,}$\xba\x01U\n\x0e\x65mail.required\x12\x33\x65mail is required and must be a valid email address\x1a\x0esize(this) > 0R\x05\x65mail\x12\x9b\x01\n\x05group\x18\x02 \x01(\tB\x84\x01\xbaH\x80\x01r\x05\x10\x01\x18\xff\x01\xba\x01v\n\x0egroup.required\x12?group name is required and must be between 1 and 255 characters\x1a#size(this) > 0 && size(this) <= 255R\x05group\x12\x9f\x01\n\x04role\x18\x03 \x01(\x0e\x32\x1b.meshtrade.iam.role.v1.RoleBn\xbaHk\x82\x01\x04\x10\x01 \x00\xba\x01\x61\n\rrole.required\x12@role is required and must be a valid role type (not UNSPECIFIED)\x1a\x0eint(this) != 0R\x04role2{\n\x0bUserService\x12l\n\x10\x41ssignRoleToUser\x12..meshtrade.iam.user.v1.AssignRoleToUserRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x42N\n\x1c\x63o.meshtrade.api.iam.user.v1Z.github.com/meshtrade/api/go/iam/user/v1;userv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034co.meshtrade.api.iam.user.v1Z.github.com/meshtrade/api/go/iam/user/v1;userv1'
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['email']._serialized_options = b'\272H\221\001r7\020\001\030\376\00120^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\\.[a-zA-Z]{2,}$\272\001U\n\016email.required\0223email is required and must be a valid email address\032\016size(this) > 0'
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['group']._loaded_options = None
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['group']._serialized_options = b'\272H\200\001r\005\020\001\030\377\001\272\001v\n\016group.required\022?group name is required and must be between 1 and 255 characters\032#size(this) > 0 && size(this) <= 255'
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['role']._serialized_options = b'\272Hk\202\001\004\020\001 \000\272\001a\n\rrole.required\022@role is required and must be a valid role type (not UNSPECIFIED)\032\016int(this) != 0'
  _globals['_USERSERVICE'].methods_by_name['AssignRoleToUser']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['AssignRoleToUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_ASSIGNROLETOUSERREQUEST']._serialized_start=199
  _globals['_ASSIGNROLETOUSERREQUEST']._serialized_end=719
  _globals['_USERSERVICE']._serialized_start=721
  _globals['_USERSERVICE']._serialized_end=844
# @@protoc_insertion_point(module_scope)
